Guides — Inmanta 2017.4dev documentation

# Guides

Note

These guides assume you have a basis understanding of the Inmanta components and have Inmanta installed on your system.

- Setup authentication
  - SSL
  - Authentication
  - External authentication providers
- Create a configuration model
  - Create a new source project
  - Initial model
  - Deploy a file
- Module Developers Guide
  - Module layout
  - Module metadata
  - Versioning
  - Extending Inmanta